kwebsp

<%include file="/app/common/html/include/static.html"/>
搜索 添加项目 下载数据 上传intapp_index.zip
删除选中
选择图片 cli运行 (脚本本身是长期运行的情况下选择) 守护进程运行(脚本可能停止的情况下选择) kwebsp项目管理器 自定义 python3.6解释器 python3.8解释器 python3.9解释器 npm运行 php7.2解释器 php7.3解释器 php7.4解释器 php8.2解释器 php8.3解释器
您必须提前在“软件管理”中安装php7.2，已安装请忽略，其他安装方式将无效 您必须提前在“软件管理”中安装php7.3，已安装请忽略，其他安装方式将无效 您必须提前在“软件管理”中安装php7.4，已安装请忽略，其他安装方式将无效 您必须提前在“软件管理”中安装php8.2，已安装请忽略，其他安装方式将无效 您必须提前在“软件管理”中安装php8.3，已安装请忽略，其他安装方式将无效
取 消 修改 添加

    {{runlog}}